#include "pykimix_c.h"

// --- Math ---
int add(int a, int b){ return a + b; }
int sub(int a, int b){ return a - b; }
int mul(int a, int b){ return a * b; }
double divd(double a, double b){ return a / b; }